@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: Lookup.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: Lookup.pm 61 2014-04-03 09:33:20Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 61 $
 
 package Lookup;
 
@@ -39,6 +39,8 @@ use strict;
 use warnings;
 use Socket;
 use IO::Socket::INET;
+use Socket;
+use AbuseWhois;
 use Log;
 
 sub Lookup {
@@ -52,57 +54,39 @@ sub Lookup {
 	my $lookup = $$opts{'lookup'};
 
 	my ($ip, $port);
+	# IPv4/port
 	if ( $lookup =~ /^(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}):(\d{1,5})$/ ) {
 		$ip   = $1;
 		$port = $2;
+		# IPv4 ICMP
+	} elsif ( $lookup =~ /^(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}):(\d+\.\d+)$/ ) {
+		$ip   = $1;
+		$port = $2;
+	# IPv4
 	} elsif ( $lookup =~ /^(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})$/ ) {
 		$ip   = $1;
 		$port = 0;
+	# IPv6/port
 	} elsif ( $lookup =~ /^([0-9a-f]+[0-9a-f:]+)\.(\d{1,5})$/ ) {
 		$ip   = $1;
+	# IPv6 ICMP
+	} elsif ( $lookup =~ /^([0-9a-f]+[0-9a-f:]+)\.(\d+\.\d+)$/ ) {
+		$ip   = $1;
+	# IPv6
 	} elsif ( $lookup =~ /^([0-9a-f]+[0-9a-f:]+)$/ ) {
 		$ip   = $1;
 		$port = 0;
-	} elsif ( $lookup =~ /^([0-9a-f]+[0-9a-f:]+\.\.[0-9a-f:]+)\.(\d{1,5})$/ ) {
-		$ip   = $1;
-		$port = $2;
-	} elsif ( $lookup =~ /^([0-9a-f]+[0-9a-f:]+\.\.[0-9a-f:]+)$/ ) {
-		$ip   = $1;
-		$port = 0;
+	} elsif ( $lookup =~ /^([0-9a-f]+[0-9a-f:]+\.\.[0-9a-f:]+)/ ) {
+		print $socket "Use IPv6 long format for IPv6lookup<br>";
+		return;
+	} else {
+		print $socket "Can not decode IP address<br>";
+		return;
 	} 
 
-	my $ipaddr = inet_aton($ip);
-	my $hostname = gethostbyaddr($ipaddr, AF_INET);
-
-	print $socket "<h3>$ip: $hostname</h3>\n";
 #   print $socket "Port: $port<br>";
 
-	my $whois_socket = IO::Socket::INET->new(
-		PeerAddr  => 'whois.cyberabuse.org',
-		PeerPort  => 43,
-		Proto	  => 'tcp',
-		timeout	  => 10 );
-
-	if ( !$whois_socket ) {
-		 print $socket "Can't connect to whoisd: $@<br>\n";
-		return;
-	}
-	
-	print $whois_socket "$ip\n";
-	print $socket "<pre>";
-	while ( <$whois_socket> ) {
-		chomp;
-		next if $_ =~ /^%/;
-		next if $_ =~ /^\[/;
-		next if $_ =~ /^$/;
-		$_ =~ s/^\s*(.+)/$1/;
-		$_ =~ s/:\s+/ /;
-		next if $_ =~ /^Source/;
-		print $socket "$_\n";
-	}
-
-	close $whois_socket;
-	print $socket "</table>";
+	AbuseWhois::Query($socket, $ip);
 
 } # End of Lookup
 
