@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: NfConf.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: NfConf.pm 69 2014-06-23 19:27:50Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 69 $
 
 package NfConf;
 
@@ -66,6 +66,7 @@ our $low_water;
 our $syslog_facility;
 our $ZIPcollected;
 our $ZIPprofiles;
+our $InterruptExpire;
 our $EXTENSIONS;
 our $PIDDIR;
 our $FILTERDIR;
@@ -74,9 +75,11 @@ our $DEBUG;
 our $AllowsSystemCMD;
 our $SIMmode;
 our $Refresh;
+our $PERL_HAS_MEMLEAK;
 our $BACKEND_PLUGINDIR;
 our $PICDIR;
-
+our $NFPROFILEOPTS;
+our $NFEXPIREOPTS;
 
 # Alerting email vars
 our $MAIL_FROM;
@@ -88,6 +91,8 @@ our $UID;
 our $GID;
 our $LogSocket;
 
+our $CYCLETIME;
+
 #
 # Loads the config from nfsen.conf file
 # returns 1 on success. 
@@ -102,6 +107,7 @@ sub LoadConfig {
 	}
 	
 	# preset default values:
+	$CYCLETIME		 = 300;
 	$DEBUG			 = 0;
 	$BASEDIR		 = undef;
 	$BINDIR			 = undef;
@@ -131,7 +137,7 @@ sub LoadConfig {
 	$syslog_facility = 'local3';
 	$RRDoffset	 	 = 0;
 	$SIMmode		 = 0;
-	$Refresh		 = 300;
+	$Refresh		 = $CYCLETIME;
 	$AllowsSystemCMD = 0;
 	$PICDIR			 = undef;
 	$FILTERDIR		 = undef;
@@ -141,8 +147,14 @@ sub LoadConfig {
 	$MAIL_BODY		 = q{Alert '@alert@' triggered at timeslot @timeslot@};
 	$SMTP_SERVER	 = '';
 
-	$ZIPcollected	 = 0;
-	$ZIPprofiles	 = 0;
+	$ZIPcollected	 = 1;
+	$ZIPprofiles	 = 1;
+	$InterruptExpire = 0;
+
+	$NFPROFILEOPTS	 = '';
+	$NFEXPIREOPTS	 = '';
+
+	$PERL_HAS_MEMLEAK = 0;
 
 	my $log_type 	= $^V =~ /5.10/ ? 'native' : 'unix';
 
@@ -216,9 +228,6 @@ sub LoadConfig {
 	}
 	$GID = $gid;
 
-	$ZIPcollected = $ZIPcollected == 0 ? '' : '-z';
-	$ZIPprofiles  = $ZIPprofiles == 0 ? '' : '-z';
-
 
 	$Log::ERROR = undef ;
 	return 1;
