@@ -1343,7 +1343,7 @@ sub DoRebuild {
 				$completed = 100;
 			}
 			if ( ($counter % $modulo ) == 0 ) {
-				print $socket ".info Rebuilding Profile '$profile': Completed: $completed\%\n";
+				print $socket ".info Rebuilding Profile '$profile': Completed: $completed\%\n" if $socket;
 				syslog('info', "Rebuilding Profile '$profile': Completed: $completed\%");
 			}
 
