@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: NfSenRC.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: NfSenRC.pm 69 2014-06-23 19:27:50Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 69 $
 
 package NfSenRC;
 
@@ -44,6 +44,7 @@ use Log;
 our %CollectorMap = ( 
 	'netflow'	=> 'nfcapd',
 	'sflow'		=> 'sfcapd',
+	'pcap'		=> 'nfpcapd',
 );
 
 sub StartCollector {
@@ -54,22 +55,21 @@ sub StartCollector {
 		print "[no collector]";
 		return;
 	}
-
 	my @SourceList;
 	my $type = undef;
 	foreach my $source ( sort keys %NfConf::sources ) {
 		my $_port = $NfConf::sources{$source}{'port'};
 		if ( $_port == $port ) {
 			push @SourceList, $source;
-		}
-		my $_type = exists $NfConf::sources{$source}{'type'} ? $NfConf::sources{$source}{'type'}: 'netflow';
-		if ( defined $type ) {
-			if ( $type ne $_type ) {
-				print "Can not start different type '$type' and '$_type' on same port!\n";
-				return;
+			my $_type = exists $NfConf::sources{$source}{'type'} ? $NfConf::sources{$source}{'type'}: 'netflow';
+			if ( defined $type ) {
+				if ( $type ne $_type ) {
+					print "Can not start different type '$type' and '$_type' on same port!\n";
+					return;
+				}
+			} else {
+				$type = $_type;
 			}
-		} else {
-			$type = $_type;
 		}
 	}
 
@@ -93,7 +93,8 @@ sub StartCollector {
 		return;
 	}
 
-	my $common_args = "-w -D -p $port -u $uid -g $gid $buffer_opts $subdirlayout -P $pidfile $NfConf::ZIPcollected $extensions";
+	my $ziparg = $NfConf::ZIPcollected ? '-z' : '';
+	my $common_args = "-w -D -p $port -u $uid -g $gid $buffer_opts $subdirlayout -P $pidfile $ziparg $extensions";
 	my $src_args;
 	my $optargs = '';
 	if ( scalar @SourceList > 1 ) {
@@ -274,7 +275,7 @@ sub NfSen_stop {
 			unlink "$NfConf::PIDDIR/nfsend.pid";
 		} else {
 			kill 'TERM', $pid || warn "Can't signal nfsend: $! ";
-			my $timeout = 300;
+			my $timeout = $NfConf::CYCLETIME;
 			while ( $timeout && -f "$NfConf::PIDDIR/nfsend.pid") {
 				print ".";
 				sleep 1;
