@@ -27,11 +27,11 @@
 #  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 #  POSSIBILITY OF SUCH DAMAGE.
 #
-#  $Author: haag $
+#  $Author: peter $
 #
-#  $Id: Nfsources.pm 67 2010-09-09 05:56:05Z haag $
+#  $Id: Nfsources.pm 69 2014-06-23 19:27:50Z peter $
 #
-#  $LastChangedRevision: 67 $
+#  $LastChangedRevision: 69 $
 
 package Nfsources;
 
@@ -231,7 +231,7 @@ sub Reconfig {
 	if ( scalar @AddSourceList > 0 ) {
 		# Add sources
 		my $now = time();
-		my $tstart = $now - ( $now % 300 );
+		my $tstart = $now - ( $now % $NfConf::CYCLETIME );
 		foreach my $source ( @AddSourceList ) {
 			print "Add source '$source'";
 			my $ret = NfProfile::AddChannel(\%profileinfo, $source, '+', 0, $NfConf::sources{$source}{'col'}, $source, []);
